@@ -44,8 +44,8 @@ def df_write_csv(df, bytesio, has_header):
     [{""key"":""ValueRaw"",""value"":""88.7""},{""key"":""Status"",""value"":""0""},{""key"":""ValueSD"",""value"":""0""},{""key"":""CollectRate"",""value"":""100.0""},{""key"":""Valid"",""value"":""0""}]",2022-04-21 00:02:00.042,11647957860,23.8549,2022-04-21 00:01:00.000,120.2696,rh,88.7
     "[{""key"":""ValueRaw"",""value"":""27""},{""key"":""Status"",""value"":""64""},{""key"":""ValueSD"",""value"":""0""},{""key"":""CollectRate"",""value"":""0.0""},{""key"":""Valid"",""value"":""4""}]",2022-04-21 00:02:00.042,11647957860,23.8549,2022-04-21 00:01:00.000,120.2696,pm2_5,27.0
     '''
-    if df.row(0)[0][0] == '[':
-        bytesio.write(b'"')
+    # if df.row(0)[0][0] == '[':
+    #     bytesio.write(b'"')
     return df.write_csv(bytesio, has_header=has_header)
 
 
