@@ -29,6 +29,11 @@ async def async_post(url, dic):
         return (await c.post(url, data=dic)).json()
 
 
-async def async_get(url):
+async def async_get_json(url):
     async with httpx.AsyncClient() as c:
         return (await c.get(url)).json()
+
+
+async def async_get_read(url):
+    async with httpx.AsyncClient() as c:
+        return (await c.get(url)).read()
