@@ -1,4 +1,5 @@
 import asyncio
+import sys
 
 import polars
 
@@ -6,6 +7,7 @@ import cameo_claw as cc
 from cameo_claw import mkdir
 from cameo_claw.client import Client
 from cameo_claw.net import url_to_filename
+from cameo_claw.remote import hourly_mean
 from cameo_claw.worker_f import pipe_download_iot_csv_gz
 import os
 
@@ -132,7 +134,9 @@ def get_lst_url_by_date(lst_device_id):
     for device_id in lst_device_id:
         for i in range(1, 32):  # range(1, 32)
             day = f'2022-03-{i:02}'
-            url = f'https://iot.epa.gov.tw/fapi_open/topic-device-daily/topic_save.industry.rawdata.material/device_{device_id}/device_{device_id}_daily_{day}.csv.gz'
+            url = f'https://static2.bowenchiu.repl.co/static/device_{device_id}_daily_{day}.csv.gz'
+            # url = f'https://iot.epa.gov.tw/fapi_open/topic-device-daily/topic_save.industry.rawdata.material/device_{device_id}/device_{device_id}_daily_{day}.csv.gz'
+            # url = f'https://static-speed.vercel.app/device_{device_id}_daily_{day}.csv.gz'
             lst_url.append(url)
     return lst_url
 
@@ -244,15 +248,47 @@ def test_nation_zip():
     return cc.zip_cache(d)
 
 
-async def test_client(api_url):
+async def test_client_hourly_mean(api_url):
     client = Client(api_url)
-    d = {
-        'target_directory': './data/topic_download_iot_csv_gz/',
-        'lst_distinct_column': ['deviceId', 'localTime', 'sensorId'],
-        'lst_column_match': [['sensorId', 'pm2_5'], ['sensorId', 'voc']],
-        'sort_column': 'localTime',
-        'lst_group_by_column': ['deviceId', 'sensorId']}
-    lst_result = await client.map(pipe_download_iot_csv_gz, get_lst_url_taipei_100()[0:10], d, int_chunk_size=100)
+    d = {'target_directory': './data/topic_download_iot_csv_gz/',
+         'lst_distinct_column': ['deviceId', 'localTime', 'sensorId'],
+         'lst_column_match': [['sensorId', 'pm2_5']],
+         'sort_column': 'localTime',
+         'lst_group_by_column': ['deviceId', 'sensorId']}
+    # lst_result = await client.map(hourly_mean, get_lst_url_taipei_100()[0:650], d, int_chunk_size=20)
+
+    # lst_result = await client.map(hourly_mean, [
+    #     "https://static2.bowenchiu.repl.co/static/big/0.csv.gz",
+    #     "https://static2.bowenchiu.repl.co/static/big/1.csv.gz",
+    #     "https://static2.bowenchiu.repl.co/static/big/2.csv.gz",
+    #     "https://static2.bowenchiu.repl.co/static/big/3.csv.gz",
+    #     "https://static2.bowenchiu.repl.co/static/big/4.csv.gz",
+    #     "https://static2.bowenchiu.repl.co/static/big/5.csv.gz",
+    #     "https://static2.bowenchiu.repl.co/static/big/6.csv.gz",
+    #     "https://static2.bowenchiu.repl.co/static/big/7.csv.gz",
+    #     "https://static2.bowenchiu.repl.co/static/big/8.csv.gz",
+    #     "https://static2.bowenchiu.repl.co/static/big/9.csv.gz",
+    # ], d, int_chunk_size=1)
+
+    lst_result = await client.map(hourly_mean, [
+        "https://static-speed.vercel.app/0.csv.gz",
+        "https://static2.bowenchiu.repl.co/static/big/1.csv.gz",
+        "https://static2.bowenchiu.repl.co/static/big/2.csv.gz",
+        "https://static2.bowenchiu.repl.co/static/big/3.csv.gz",
+        "https://static2.bowenchiu.repl.co/static/big/4.csv.gz",
+        "https://static2.bowenchiu.repl.co/static/big/5.csv.gz",
+        "https://static2.bowenchiu.repl.co/static/big/6.csv.gz",
+        "https://static2.bowenchiu.repl.co/static/big/7.csv.gz",
+        "https://static2.bowenchiu.repl.co/static/big/8.csv.gz",
+        "https://static2.bowenchiu.repl.co/static/big/9.csv.gz",
+    ], d, int_chunk_size=1)
+
+    # print(len(lst_result))
+    # lst_result 裡面的每個 item 大致長這樣
+    # {'is_success': True,
+    #  'url': 'https://iot.epa.gov.tw/fapi_open/topic-device-daily/topic_save.industry.rawdata.material/device_10180507985/device_10180507985_daily_2022-03-12.csv.gz',
+    #  'csv': 'hourly_time,deviceId,sensorId,lat,lon,value\n2022-03-12 00,10180507985,pm2_5,25.0620133,121.5963933,14.574237288135587\n2022-03-12 22,10180507985,pm2_5,25.0620866,121.596355,11.152833333333332\n2022-03-12 04,10180507985,pm2_5,25.0620116,121.5964016,12.943666666666672\n2022
+    # todo 拿到 lst_result 之後要把 ['csv'] 看是要儲存還是要做什麼
 
 
 def pipe_download(url, d):
@@ -264,7 +300,7 @@ def pipe_download(url, d):
 
 
 def test_pipe_download():
-    d = {'lst_url': get_lst_url_taipei_100(),
+    d = {'lst_url': get_lst_url_taipei_100()[0:650],
          'target_directory': './data/topic_pipe_download/',
          }
     for int_progress, dic_result in cc.pipe(pipe_download, d['lst_url'], d):
@@ -359,9 +395,9 @@ if __name__ == '__main__':
     # test_pipe_download_iot_zip()
     # test_pipe_download_iot_csv_gz()
     # test_nation_zip()
-    # test_pipe_download() # 純下載無計算
+    # test_pipe_download()  # 純下載無計算
     # test_local()
     # test_local_csv()
     # test_local_csv_to_parquet()
     # test_local_parquet_compute()
-    asyncio.run(test_client('http://0.0.0.0:8000/api/'))
+    asyncio.run(test_client_hourly_mean(sys.argv[1]))
